@@ -9,7 +9,7 @@ FourdigitsPortletTwitterMessageFactory as _
 from fourdigits.portlet.twitter import twitter
 import re
 from urllib2 import URLError
-from time import time
+
 
 # Match and capture urls
 urlsRegexp = re.compile(r"""
@@ -44,11 +44,6 @@ emailRegexp = re.compile(r"""
     """, re.VERBOSE | re.IGNORECASE)
 
 
-def _twitter_cachekey(method, self):
-    """A cachekey of 5 minutes"""
-    return time() // (60 * 5)
-
-
 def expand_tweet(str):
     """This method takes a string, parses it for URLs, hashtags and mentions
        and returns a hyperlinked string."""
@@ -82,6 +77,11 @@ class IFourdigitsPortletTwitter(IPortletDataProvider):
         description=_(u"The tweets of this user will be shown"),
         required=False,)
 
+    userinfo = schema.Bool(
+        title=_(u"Show user info?"),
+        description=_(u"Show info of the Twitter user?"),
+        required=False,)
+
     includerts = schema.Bool(
         title=_(u"Include retweets"),
         description=_(u"Include retweets of the user's account?"),
@@ -90,14 +90,12 @@ class IFourdigitsPortletTwitter(IPortletDataProvider):
 
     search = schema.Text(
         title=_(u"Search"),
-        description=_(u"The tweets containing this text will be shown\
-                      enter one per line, hashtags are allowed"),
+        description=_(u"The tweets containing this text will be shown enter one per line, hashtags are allowed"),
         required=False,)
 
     filtertext = schema.Text(
         title=_(u"Filtertext"),
-        description=_(u"If a message containes (curse) words in the filtertext\
-                      it wont be shown, one per line"),
+        description=_(u"If a message containes (curse) words in the filtertext it wont be shown, one per line"),
         required=False,)
 
     userdisplay = schema.Int(
@@ -121,9 +119,7 @@ class IFourdigitsPortletTwitter(IPortletDataProvider):
 
     language = schema.Text(
         title=_("Languagefilter"),
-        description=_("Language ISO code for the tweets (e.g.: en, nl, fr), \
-                      if you like to filter on language\
-                      one per line"),
+        description=_("Language ISO code for the tweets (e.g.: en, nl, fr), if you like to filter on language one per line"),
         required=False,
     )
     userpictures = schema.Bool(
@@ -142,10 +138,12 @@ class Assignment(base.Assignment):
 
     implements(IFourdigitsPortletTwitter)
     includerts = True
+    userinfo = True
 
     def __init__(self, name=u"", username=u"", search=u"", filtertext="",
                  userdisplay=5, searchdisplay=5, searchlimit=40,
-                 language="", userpictures=False, includerts=True):
+                 language="", userpictures=False, includerts=True,
+                 userinfo=False):
         self.name = name
         self.username = username
         self.search = search
@@ -156,6 +154,7 @@ class Assignment(base.Assignment):
         self.language = language
         self.userpictures = userpictures
         self.includerts = includerts
+        self.userinfo = userinfo
 
     @property
     def title(self):
@@ -188,21 +187,32 @@ class Renderer(base.Renderer):
     def expand(self, str):
         return expand_tweet(str)
 
+    def showuserinfo(self):
+        """Should we show userinfo"""
+        if self.data.userinfo:
+            return True
+        return False
+
+    def getuserinfo(self):
+        """Get twitter user info"""
+        userinfo = self.twapi.GetUser(self.data.username)
+        return userinfo
+
     def twittermessages(self):
         """Twitter messages"""
-        return self.getTweets()
+        return self.gettweets()
 
-    def getTweetsOfUser(self, username, userpictures, includerts):
+    def gettweetsofuser(self, username, userpictures, includerts):
         """Return the tweets of a certain user"""
         try:
-
             tweets = self.twapi.GetUserTimeline(username,
-                                                includerts=includerts)
+                                                include_rts=includerts,
+                                                include_entities=True)
         except URLError:
             tweets = []
         return tweets
 
-    def getTweetsBySearch(self, searchterms, searchlimit, language):
+    def gettweetsbysearch(self, searchterms, searchlimit, language):
         """Return tweets based on a search query"""
         searchterms = searchterms.encode('utf-8')
         searchterms = searchterms.split('\n')
@@ -216,8 +226,8 @@ class Renderer(base.Renderer):
                 tweets = []
         return tweets
 
-    def getTweets(self):
-        """get the tweets and filter them"""
+    def gettweets(self):
+        """Get the tweets and filter them"""
         username = self.data.username
         searchterms = self.data.search
         userdisplay = self.data.userdisplay
@@ -233,7 +243,7 @@ class Renderer(base.Renderer):
 
         # get tweets of username
         if username:
-            tweets = self.getTweetsOfUser(username,
+            tweets = self.gettweetsofuser(username,
                                           userpictures,
                                           includerts)
         tweets = tweets[:userdisplay]
@@ -245,11 +255,11 @@ class Renderer(base.Renderer):
                 languages = languages.split('\n')
                 for lang in languages:
                     lang = str(lang.encode('utf-8'))
-                    searchresults += self.getTweetsBySearch(searchterms,
+                    searchresults += self.gettweetsbysearch(searchterms,
                                                             searchlimit,
                                                             language=lang)
             else:
-                searchresults += self.getTweetsBySearch(searchterms,
+                searchresults += self.gettweetsbysearch(searchterms,
                                                         searchlimit,
                                                         language="")
             # Only add tweets which are not already in the user results
@@ -293,6 +303,8 @@ class AddForm(base.AddForm):
     constructs the assignment that is being added.
     """
     form_fields = form.Fields(IFourdigitsPortletTwitter)
+    label = _(u"Twitter portlet")
+    description = _(u"This portlet displays tweets. Please keep note that some settings will apply after 5 minutes.")
 
     def create(self, data):
         return Assignment(**data)
@@ -305,3 +317,5 @@ class EditForm(base.EditForm):
     zope.formlib which fields to display.
     """
     form_fields = form.Fields(IFourdigitsPortletTwitter)
+    label = _(u"Twitter portlet")
+    description = _(u"This portlet displays tweets. Please keep note that some settings will apply after 5 minutes.")
